# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/area_of_interest_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2
from global_vo_grpc_service.protos import mission_api_pb2 as global__vo__grpc__service_dot_protos_dot_mission__api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8global_vo_grpc_service/protos/area_of_interest_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\x1a/global_vo_grpc_service/protos/mission_api.proto\"\xa9\x01\n\x0e\x41reaOfInterest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x17\n\x0fgeo_polygon_wkt\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"N\n!FindOrCreateAreaOfInterestRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"q\n\"FindOrCreateAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"J\n\x1d\x46indAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"m\n\x1e\x46indAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"G\n\x1aListAreaOfInterestsRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"k\n\x1bListAreaOfInterestsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12*\n\x11\x61rea_of_interests\x18\x02 \x03(\x0b\x32\x0f.AreaOfInterest\"L\n\x1fUpdateAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"o\n UpdateAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"L\n\x1f\x44\x65leteAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"o\n DeleteAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"u\n&GetAreaOfInterestOverlapPercentRequest\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"\x92\x01\n\'GetAreaOfInterestOverlapPercentResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\x12\x1a\n\x12overlap_percentage\x18\x03 \x01(\x02\"<\n\x1fGetAoiKmlDataByMissionIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\":\n GetAoiKmlDataByMissionIdResponse\x12\x16\n\x0ekml_data_bytes\x18\x01 \x01(\x0c\x32\xc2\x05\n\x11\x41reaOfInterestApi\x12\x65\n\x1a\x46indOrCreateAreaOfInterest\x12\".FindOrCreateAreaOfInterestRequest\x1a#.FindOrCreateAreaOfInterestResponse\x12Y\n\x16\x46indAreaOfInterestById\x12\x1e.FindAreaOfInterestByIdRequest\x1a\x1f.FindAreaOfInterestByIdResponse\x12P\n\x13ListAreaOfInterests\x12\x1b.ListAreaOfInterestsRequest\x1a\x1c.ListAreaOfInterestsResponse\x12_\n\x18UpdateAreaOfInterestById\x12 .UpdateAreaOfInterestByIdRequest\x1a!.UpdateAreaOfInterestByIdResponse\x12_\n\x18\x44\x65leteAreaOfInterestById\x12 .DeleteAreaOfInterestByIdRequest\x1a!.DeleteAreaOfInterestByIdResponse\x12t\n\x1fGetAreaOfInterestOverlapPercent\x12\'.GetAreaOfInterestOverlapPercentRequest\x1a(.GetAreaOfInterestOverlapPercentResponse\x12\x61\n\x18GetAoiKmlDataByMissionId\x12 .GetAoiKmlDataByMissionIdRequest\x1a!.GetAoiKmlDataByMissionIdResponse0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.area_of_interest_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AREAOFINTEREST._serialized_start=186
  _AREAOFINTEREST._serialized_end=355
  _FINDORCREATEAREAOFINTERESTREQUEST._serialized_start=357
  _FINDORCREATEAREAOFINTERESTREQUEST._serialized_end=435
  _FINDORCREATEAREAOFINTERESTRESPONSE._serialized_start=437
  _FINDORCREATEAREAOFINTERESTRESPONSE._serialized_end=550
  _FINDAREAOFINTERESTBYIDREQUEST._serialized_start=552
  _FINDAREAOFINTERESTBYIDREQUEST._serialized_end=626
  _FINDAREAOFINTERESTBYIDRESPONSE._serialized_start=628
  _FINDAREAOFINTERESTBYIDRESPONSE._serialized_end=737
  _LISTAREAOFINTERESTSREQUEST._serialized_start=739
  _LISTAREAOFINTERESTSREQUEST._serialized_end=810
  _LISTAREAOFINTERESTSRESPONSE._serialized_start=812
  _LISTAREAOFINTERESTSRESPONSE._serialized_end=919
  _UPDATEAREAOFINTERESTBYIDREQUEST._serialized_start=921
  _UPDATEAREAOFINTERESTBYIDREQUEST._serialized_end=997
  _UPDATEAREAOFINTERESTBYIDRESPONSE._serialized_start=999
  _UPDATEAREAOFINTERESTBYIDRESPONSE._serialized_end=1110
  _DELETEAREAOFINTERESTBYIDREQUEST._serialized_start=1112
  _DELETEAREAOFINTERESTBYIDREQUEST._serialized_end=1188
  _DELETEAREAOFINTERESTBYIDRESPONSE._serialized_start=1190
  _DELETEAREAOFINTERESTBYIDRESPONSE._serialized_end=1301
  _GETAREAOFINTERESTOVERLAPPERCENTREQUEST._serialized_start=1303
  _GETAREAOFINTERESTOVERLAPPERCENTREQUEST._serialized_end=1420
  _GETAREAOFINTERESTOVERLAPPERCENTRESPONSE._serialized_start=1423
  _GETAREAOFINTERESTOVERLAPPERCENTRESPONSE._serialized_end=1569
  _GETAOIKMLDATABYMISSIONIDREQUEST._serialized_start=1571
  _GETAOIKMLDATABYMISSIONIDREQUEST._serialized_end=1631
  _GETAOIKMLDATABYMISSIONIDRESPONSE._serialized_start=1633
  _GETAOIKMLDATABYMISSIONIDRESPONSE._serialized_end=1691
  _AREAOFINTERESTAPI._serialized_start=1694
  _AREAOFINTERESTAPI._serialized_end=2400
# @@protoc_insertion_point(module_scope)
