# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/metric_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.global_vo_grpc_service/protos/metric_api.proto\x1a)global_vo_grpc_service/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x1c\n\x0bMetricValue\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\"k\n\x11MetricValueStruct\x12*\n\tdata_dict\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\tdata_list\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\"7\n!FindMissionDetectionsCountRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"c\n\"FindMissionDetectionsCountResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.MetricValue\"b\n(FindMissionDetectionCountsByStateRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\x12\"\n\x1a\x65xclude_single_pole_pylons\x18\x02 \x01(\x08\"p\n)FindMissionDetectionCountsByStateResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.MetricValueStruct\"6\n GetTotalImagesByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"b\n!GetTotalImagesByMissionIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.MetricValue2\xd2\x02\n\tMetricApi\x12\x65\n\x1a\x46indMissionDetectionCounts\x12\".FindMissionDetectionsCountRequest\x1a#.FindMissionDetectionsCountResponse\x12z\n!FindMissionDetectionCountsByState\x12).FindMissionDetectionCountsByStateRequest\x1a*.FindMissionDetectionCountsByStateResponse\x12\x62\n\x19GetTotalImagesByMissionId\x12!.GetTotalImagesByMissionIdRequest\x1a\".GetTotalImagesByMissionIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.metric_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _METRICVALUE._serialized_start=123
  _METRICVALUE._serialized_end=151
  _METRICVALUESTRUCT._serialized_start=153
  _METRICVALUESTRUCT._serialized_end=260
  _FINDMISSIONDETECTIONSCOUNTREQUEST._serialized_start=262
  _FINDMISSIONDETECTIONSCOUNTREQUEST._serialized_end=317
  _FINDMISSIONDETECTIONSCOUNTRESPONSE._serialized_start=319
  _FINDMISSIONDETECTIONSCOUNTRESPONSE._serialized_end=418
  _FINDMISSIONDETECTIONCOUNTSBYSTATEREQUEST._serialized_start=420
  _FINDMISSIONDETECTIONCOUNTSBYSTATEREQUEST._serialized_end=518
  _FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE._serialized_start=520
  _FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE._serialized_end=632
  _GETTOTALIMAGESBYMISSIONIDREQUEST._serialized_start=634
  _GETTOTALIMAGESBYMISSIONIDREQUEST._serialized_end=688
  _GETTOTALIMAGESBYMISSIONIDRESPONSE._serialized_start=690
  _GETTOTALIMAGESBYMISSIONIDRESPONSE._serialized_end=788
  _METRICAPI._serialized_start=791
  _METRICAPI._serialized_end=1129
# @@protoc_insertion_point(module_scope)
