# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/utils.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)global_vo_grpc_service/protos/utils.proto\"M\n\x07GeoBbox\x12\x0f\n\x07min_lat\x18\x01 \x01(\x02\x12\x0f\n\x07max_lat\x18\x02 \x01(\x02\x12\x0f\n\x07min_lon\x18\x03 \x01(\x02\x12\x0f\n\x07max_lon\x18\x04 \x01(\x02\"$\n\x08GeoPoint\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lon\x18\x02 \x01(\x02*q\n\nChangeType\x12\x17\n\x13UNKNOWN_CHANGE_TYPE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x08\n\x04READ\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04\x12\n\n\x06\x45XISTS\x10\x05\x12\r\n\tNOT_FOUND\x10\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.utils_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANGETYPE._serialized_start=162
  _CHANGETYPE._serialized_end=275
  _GEOBBOX._serialized_start=45
  _GEOBBOX._serialized_end=122
  _GEOPOINT._serialized_start=124
  _GEOPOINT._serialized_end=160
# @@protoc_insertion_point(module_scope)
