# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_grpc_service/protos/image_data_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-data_grpc_service/protos/image_data_api.proto\"+\n\x17GetImageDataByIdRequest\x12\x10\n\x08image_id\x18\x01 \x01(\x05\"4\n\x18GetImageDataByIdResponse\x12\x18\n\x10image_data_bytes\x18\x01 \x01(\x0c\x32Y\n\x0cImageDataApi\x12I\n\x10GetImageDataById\x12\x18.GetImageDataByIdRequest\x1a\x19.GetImageDataByIdResponse0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_grpc_service.protos.image_data_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETIMAGEDATABYIDREQUEST._serialized_start=49
  _GETIMAGEDATABYIDREQUEST._serialized_end=92
  _GETIMAGEDATABYIDRESPONSE._serialized_start=94
  _GETIMAGEDATABYIDRESPONSE._serialized_end=146
  _IMAGEDATAAPI._serialized_start=148
  _IMAGEDATAAPI._serialized_end=237
# @@protoc_insertion_point(module_scope)
