# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/mission_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/global_vo_grpc_service/protos/mission_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\"\x98\x01\n\x07Mission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x14\x43reateMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x15\x43reateMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"0\n\x13ListMissionsRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x14ListMissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1a\n\x08missions\x18\x02 \x03(\x0b\x32\x08.Mission\"3\n\x16\x46indMissionByIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"V\n\x17\x46indMissionByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"=\n LockMissionAreaOfInterestRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"`\n!LockMissionAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"1\n\x14\x44\x65leteMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x15\x44\x65leteMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"5\n\x18UpdateMissionByIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"X\n\x19UpdateMissionByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission2\xbf\x03\n\nMissionApi\x12>\n\rCreateMission\x12\x15.CreateMissionRequest\x1a\x16.CreateMissionResponse\x12;\n\x0cListMissions\x12\x14.ListMissionsRequest\x1a\x15.ListMissionsResponse\x12\x44\n\x0f\x46indMissionById\x12\x17.FindMissionByIdRequest\x1a\x18.FindMissionByIdResponse\x12\x62\n\x19LockMissionAreaOfInterest\x12!.LockMissionAreaOfInterestRequest\x1a\".LockMissionAreaOfInterestResponse\x12>\n\rDeleteMission\x12\x15.DeleteMissionRequest\x1a\x16.DeleteMissionResponse\x12J\n\x11UpdateMissionById\x12\x19.UpdateMissionByIdRequest\x1a\x1a.UpdateMissionByIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.mission_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MISSION._serialized_start=128
  _MISSION._serialized_end=280
  _CREATEMISSIONREQUEST._serialized_start=282
  _CREATEMISSIONREQUEST._serialized_end=331
  _CREATEMISSIONRESPONSE._serialized_start=333
  _CREATEMISSIONRESPONSE._serialized_end=417
  _LISTMISSIONSREQUEST._serialized_start=419
  _LISTMISSIONSREQUEST._serialized_end=467
  _LISTMISSIONSRESPONSE._serialized_start=469
  _LISTMISSIONSRESPONSE._serialized_end=553
  _FINDMISSIONBYIDREQUEST._serialized_start=555
  _FINDMISSIONBYIDREQUEST._serialized_end=606
  _FINDMISSIONBYIDRESPONSE._serialized_start=608
  _FINDMISSIONBYIDRESPONSE._serialized_end=694
  _LOCKMISSIONAREAOFINTERESTREQUEST._serialized_start=696
  _LOCKMISSIONAREAOFINTERESTREQUEST._serialized_end=757
  _LOCKMISSIONAREAOFINTERESTRESPONSE._serialized_start=759
  _LOCKMISSIONAREAOFINTERESTRESPONSE._serialized_end=855
  _DELETEMISSIONREQUEST._serialized_start=857
  _DELETEMISSIONREQUEST._serialized_end=906
  _DELETEMISSIONRESPONSE._serialized_start=908
  _DELETEMISSIONRESPONSE._serialized_end=992
  _UPDATEMISSIONBYIDREQUEST._serialized_start=994
  _UPDATEMISSIONBYIDREQUEST._serialized_end=1047
  _UPDATEMISSIONBYIDRESPONSE._serialized_start=1049
  _UPDATEMISSIONBYIDRESPONSE._serialized_end=1137
  _MISSIONAPI._serialized_start=1140
  _MISSIONAPI._serialized_end=1587
# @@protoc_insertion_point(module_scope)
