# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/detection_instance_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import detection_api_pb2 as global__vo__grpc__service_dot_protos_dot_detection__api__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:global_vo_grpc_service/protos/detection_instance_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31global_vo_grpc_service/protos/detection_api.proto\x1a)global_vo_grpc_service/protos/utils.proto\"\xf4\x03\n\x11\x44\x65tectionInstance\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\x12\x0f\n\x07part_id\x18\x03 \x01(\x05\x12\x10\n\x08image_id\x18\x04 \x01(\x05\x12\x14\n\x0c\x64\x65tection_id\x18\x05 \x01(\x05\x12\x11\n\tsource_id\x18\x06 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x07 \x01(\x0b\x32\x08.GeoBbox\x12\r\n\x05score\x18\x08 \x01(\x02\x12\x0e\n\x06height\x18\t \x01(\x02\x12/\n\x0b\x64\x65tected_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x63\x61tegory_id\x18\x0e \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x0f \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x10 \x01(\x0b\x32\t.GeoPoint\x12\r\n\x05state\x18\x11 \x01(\t\"}\n,FindOrCreateDetectionInstanceViaHumanRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"\x81\x01\n-FindOrCreateDetectionInstanceViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\x7f\n.FindOrCreateDetectionInstanceViaMachineRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"\x83\x01\n/FindOrCreateDetectionInstanceViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"W\n%GetDetectionInstancesByImageIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"{\n&GetDetectionInstancesByImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"_\n-UpdateDetectionInstanceGeoBboxViaHumanRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"\x82\x01\n.UpdateDetectionInstanceGeoBboxViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"a\n/UpdateDetectionInstanceGeoBboxViaMachineRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"\x84\x01\n0UpdateDetectionInstanceGeoBboxViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"T\n\"DeleteDetectionInstanceByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n#DeleteDetectionInstanceByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"j\n\'TransitionDetectionInstanceStateRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x0f\n\x07trigger\x18\x02 \x01(\t\"\x8b\x01\n(TransitionDetectionInstanceStateResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\r\n\x05state\x18\x02 \x01(\t\x12.\n\x12\x64\x65tection_instance\x18\x03 \x01(\x0b\x32\x12.DetectionInstance\"U\n#GetDetectionInstanceBboxByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n$GetDetectionInstanceBboxByIdResponse\x12\r\n\x05min_x\x18\x01 \x01(\x05\x12\r\n\x05max_x\x18\x02 \x01(\x05\x12\r\n\x05min_y\x18\x03 \x01(\x05\x12\r\n\x05max_y\x18\x04 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x05 \x01(\x05\"V\n$GetDetectionInstanceStateByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"y\n%GetDetectionInstanceStateByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"Q\n\x1fGetDetectionInstanceByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"t\n GetDetectionInstanceByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\xa4\x01\n/UpdateDetectionInstanceGeoPointsViaHumanRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"\x84\x01\n0UpdateDetectionInstanceGeoPointsViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\xa6\x01\n1UpdateDetectionInstanceGeoPointsViaMachineRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"\x86\x01\n2UpdateDetectionInstanceGeoPointsViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance2\x8a\x0c\n\x14\x44\x65tectionInstanceApi\x12h\n\x1b\x44\x65leteDetectionInstanceById\x12#.DeleteDetectionInstanceByIdRequest\x1a$.DeleteDetectionInstanceByIdResponse\x12\x86\x01\n%FindOrCreateDetectionInstanceViaHuman\x12-.FindOrCreateDetectionInstanceViaHumanRequest\x1a..FindOrCreateDetectionInstanceViaHumanResponse\x12\x8c\x01\n\'FindOrCreateDetectionInstanceViaMachine\x12/.FindOrCreateDetectionInstanceViaMachineRequest\x1a\x30.FindOrCreateDetectionInstanceViaMachineResponse\x12k\n\x1cGetDetectionInstanceBboxById\x12$.GetDetectionInstanceBboxByIdRequest\x1a%.GetDetectionInstanceBboxByIdResponse\x12n\n\x1dGetDetectionInstanceStateById\x12%.GetDetectionInstanceStateByIdRequest\x1a&.GetDetectionInstanceStateByIdResponse\x12_\n\x18GetDetectionInstanceById\x12 .GetDetectionInstanceByIdRequest\x1a!.GetDetectionInstanceByIdResponse\x12q\n\x1eGetDetectionInstancesByImageId\x12&.GetDetectionInstancesByImageIdRequest\x1a\'.GetDetectionInstancesByImageIdResponse\x12w\n TransitionDetectionInstanceState\x12(.TransitionDetectionInstanceStateRequest\x1a).TransitionDetectionInstanceStateResponse\x12\x89\x01\n&UpdateDetectionInstanceGeoBboxViaHuman\x12..UpdateDetectionInstanceGeoBboxViaHumanRequest\x1a/.UpdateDetectionInstanceGeoBboxViaHumanResponse\x12\x8f\x01\n(UpdateDetectionInstanceGeoBboxViaMachine\x12\x30.UpdateDetectionInstanceGeoBboxViaMachineRequest\x1a\x31.UpdateDetectionInstanceGeoBboxViaMachineResponse\x12\x8f\x01\n(UpdateDetectionInstanceGeoPointsViaHuman\x12\x30.UpdateDetectionInstanceGeoPointsViaHumanRequest\x1a\x31.UpdateDetectionInstanceGeoPointsViaHumanResponse\x12\x95\x01\n*UpdateDetectionInstanceGeoPointsViaMachine\x12\x32.UpdateDetectionInstanceGeoPointsViaMachineRequest\x1a\x33.UpdateDetectionInstanceGeoPointsViaMachineResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.detection_instance_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETECTIONINSTANCE._serialized_start=190
  _DETECTIONINSTANCE._serialized_end=690
  _FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST._serialized_start=692
  _FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST._serialized_end=817
  _FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE._serialized_start=820
  _FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE._serialized_end=949
  _FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST._serialized_start=951
  _FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST._serialized_end=1078
  _FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE._serialized_start=1081
  _FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE._serialized_end=1212
  _GETDETECTIONINSTANCESBYIMAGEIDREQUEST._serialized_start=1214
  _GETDETECTIONINSTANCESBYIMAGEIDREQUEST._serialized_end=1301
  _GETDETECTIONINSTANCESBYIMAGEIDRESPONSE._serialized_start=1303
  _GETDETECTIONINSTANCESBYIMAGEIDRESPONSE._serialized_end=1426
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST._serialized_start=1428
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST._serialized_end=1523
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE._serialized_start=1526
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE._serialized_end=1656
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST._serialized_start=1658
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST._serialized_end=1755
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE._serialized_start=1758
  _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE._serialized_end=1890
  _DELETEDETECTIONINSTANCEBYIDREQUEST._serialized_start=1892
  _DELETEDETECTIONINSTANCEBYIDREQUEST._serialized_end=1976
  _DELETEDETECTIONINSTANCEBYIDRESPONSE._serialized_start=1978
  _DELETEDETECTIONINSTANCEBYIDRESPONSE._serialized_end=2097
  _TRANSITIONDETECTIONINSTANCESTATEREQUEST._serialized_start=2099
  _TRANSITIONDETECTIONINSTANCESTATEREQUEST._serialized_end=2205
  _TRANSITIONDETECTIONINSTANCESTATERESPONSE._serialized_start=2208
  _TRANSITIONDETECTIONINSTANCESTATERESPONSE._serialized_end=2347
  _GETDETECTIONINSTANCEBBOXBYIDREQUEST._serialized_start=2349
  _GETDETECTIONINSTANCEBBOXBYIDREQUEST._serialized_end=2434
  _GETDETECTIONINSTANCEBBOXBYIDRESPONSE._serialized_start=2436
  _GETDETECTIONINSTANCEBBOXBYIDRESPONSE._serialized_end=2555
  _GETDETECTIONINSTANCESTATEBYIDREQUEST._serialized_start=2557
  _GETDETECTIONINSTANCESTATEBYIDREQUEST._serialized_end=2643
  _GETDETECTIONINSTANCESTATEBYIDRESPONSE._serialized_start=2645
  _GETDETECTIONINSTANCESTATEBYIDRESPONSE._serialized_end=2766
  _GETDETECTIONINSTANCEBYIDREQUEST._serialized_start=2768
  _GETDETECTIONINSTANCEBYIDREQUEST._serialized_end=2849
  _GETDETECTIONINSTANCEBYIDRESPONSE._serialized_start=2851
  _GETDETECTIONINSTANCEBYIDRESPONSE._serialized_end=2967
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST._serialized_start=2970
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST._serialized_end=3134
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE._serialized_start=3137
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE._serialized_end=3269
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST._serialized_start=3272
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST._serialized_end=3438
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE._serialized_start=3441
  _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE._serialized_end=3575
  _DETECTIONINSTANCEAPI._serialized_start=3578
  _DETECTIONINSTANCEAPI._serialized_end=5124
# @@protoc_insertion_point(module_scope)
